@@ -25,6 +25,73 @@ class ordenes_trabajos extends Model
     }
 
 
+    public static function countOtPendientesDePago()
+    { 
+
+        return DB::table('ordenes_trabajos')
+        // ->distinct()
+        ->select('pagos.numero_ot',
+        "ordenes_trabajos.fecha_ingreso",
+        "ordenes_trabajos.fecha_entrega",
+        "medios_pagos.descripcion as descripcionmediodepago",
+        'pagos.total as totalmediopago',
+        "clientes.rut",
+        "pagos.id as iddelpago" ,
+         "clientes.razon_social",
+         "estado_orden_trabajo.descripcion as descripcionestado",
+         DB::raw("(SELECT descripcion FROM sucursales WHERE id = ordenes_trabajos.sucursales_id) as nombre_sucursal")
+
+        )
+        ->join("clientes","clientes.id","=","ordenes_trabajos.clientes_id")
+
+        ->join('pagos', 'pagos.numero_ot', '=', 'ordenes_trabajos.numero_ot')
+        ->join("estado_orden_trabajo","estado_orden_trabajo.id","=","ordenes_trabajos.estado_orden_trabajo_id")
+
+        ->join('medios_pagos', 'pagos.medios_pagos_id', '=', 'medios_pagos.id')
+        ->where('medios_pagos.contabiliza', '=', 1)
+        ->where("ordenes_trabajos.eliminado","=",0)
+        ->where("pagos.total","!=",0)
+
+        
+        ->where("ordenes_trabajos.historial_ot","=",'activo')
+
+        ->get();
+    }
+
+    public static function obtenerOtSinPagoContabilizado()
+{
+
+    
+    return DB::table('ordenes_trabajos')
+        // ->distinct()
+        ->select('pagos.numero_ot',
+        "ordenes_trabajos.fecha_ingreso",
+        "ordenes_trabajos.fecha_entrega",
+        "medios_pagos.descripcion as descripcionmediodepago",
+        'pagos.total as totalmediopago',
+        "clientes.rut",
+        "pagos.id as iddelpago" ,
+         "clientes.razon_social",
+         "estado_orden_trabajo.descripcion as descripcionestado",
+         DB::raw("(SELECT descripcion FROM sucursales WHERE id = ordenes_trabajos.sucursales_id) as nombre_sucursal")
+
+        )
+        ->join("clientes","clientes.id","=","ordenes_trabajos.clientes_id")
+
+        ->join('pagos', 'pagos.numero_ot', '=', 'ordenes_trabajos.numero_ot')
+        ->join("estado_orden_trabajo","estado_orden_trabajo.id","=","ordenes_trabajos.estado_orden_trabajo_id")
+
+        ->join('medios_pagos', 'pagos.medios_pagos_id', '=', 'medios_pagos.id')
+        ->where('medios_pagos.contabiliza', '=', 1)
+        ->where("ordenes_trabajos.eliminado","=",0)
+        ->where("pagos.total","!=",0)
+
+        
+        ->where("ordenes_trabajos.historial_ot","=",'activo')
+
+        ->get();
+}
+
     public static function datosdelequipo($data)
     {
         return   $data = ordenes_trabajos::select(
@@ -33,8 +100,10 @@ class ordenes_trabajos extends Model
          "combustibles.nombre as nombrecombustible",
          "ordenes_trabajos.pendiente",
          "ordenes_trabajos.abono",
-         "ordenes_trabajos.total"
-        
+         "ordenes_trabajos.total",
+         "combustibles.id as idcombustible",
+         "ordenes_trabajos.fecha_ingreso",
+         "ordenes_trabajos.fecha_entrega"
         )
         ->join("equipos","equipos.id","=","ordenes_trabajos.equipos_id")
         ->join("combustibles","combustibles.id","=","equipos.combustible_id")
@@ -68,6 +137,9 @@ class ordenes_trabajos extends Model
          "clientes.razon_social",
          "ordenes_trabajos.id"
          ,"ordenes_trabajos.fecha_ingreso"
+         ,"ordenes_trabajos.fecha_modificacion"
+         ,"ordenes_trabajos.fecha_ingreso_actualizacion"
+         
          ,"ordenes_trabajos.numero_ot"
 
          ,"ordenes_trabajos.fecha_entrega")
@@ -315,7 +387,9 @@ class ordenes_trabajos extends Model
                 //filtrar por usuarios
                 if(strtolower($tipoUsuario) == "operario" ){
 
-                    $getData->where("ordenes_trabajos.operario_id","=", Auth::user()->id);
+                    // $getData->where("ordenes_trabajos.operario_id","=", Auth::user()->id);
+                    $getData->where("ordenes_trabajos.sucursales_id","=", Auth::user()->sucursales_id);
+
         
                 }
 
