@@ -98,21 +98,39 @@
 
                      </div>
 
+                     <div class="mb-3 col-3">
+                        <label for="" class="form-label">Fecha Ingreso</label>
+                        @if (isset($ordenes_trabajos[0]->fecha_ingreso))
+                            <input type="date" name="fecha_ingreso" class="form-control"
+                                value="{{ \Carbon\Carbon::createFromDate($ordenes_trabajos[0]->fecha_ingreso)->format('Y-m-d') }}">
+                        @else
+                            <input type="date" name="fecha_ingreso" class="form-control" value="">
+                        @endif
+                    
+                    </div>
 
-                     <div class="mb-3 col-6">
+
+                     <div class="mb-3 col-3">
+                        <label for="" class="form-label">Fecha entrega</label>
+                        @if (isset($ordenes_trabajos[0]->fecha_entrega))
+                            <input type="date" name="fechaentrega" class="form-control"
+                                value="{{ \Carbon\Carbon::createFromDate($ordenes_trabajos[0]->fecha_entrega)->format('Y-m-d') }}">
+                        @else
+                            <input type="date" name="fechaentrega" class="form-control" value="">
+                        @endif
+                    
+                    </div>
+
+                     {{-- <div class="mb-3 col-6">
                          <label for="" class="form-label">Fecha entrega</label>
-{{-- {{$ordenes_trabajos[0]->fecha_entrega}} --}}
                          @if (isset($ordenes_trabajos[0]->fecha_entrega))
                              <input type="date" name="fechaentrega" class="form-control"
                                  value="{{ \Carbon\Carbon::createFromDate($ordenes_trabajos[0]->fecha_entrega)->format('Y-m-d') }}">
                          @else
                              <input type="date" name="fechaentrega" class="form-control" value="">
                          @endif
-                         {{-- <input type="date" class="form-control"  value="{{ Carbon\Carbon::createFromDate($ordenes_trabajos[0]->fecha_entrega ?? '')->format('d-m-Y') }}"> --}}
-                         {{-- <input type="text" class="form-control"
-                            value="{{ Carbon\Carbon::createFromDate($ordenes_trabajos[0]->fecha_entrega ?? '')->format('d-m-Y') }}"> --}}
-
-                     </div>
+                     
+                     </div> --}}
                      {{-- value="{{Carbon\Carbon::createFromDate($orden_trabajo[0]->fecha_entrega ?? '')->format('d-m-Y')}}" --}}
                      <div class="mb-3 col-13">
                          <label for="" class="form-label">Comentario</label>
@@ -136,7 +154,64 @@
                         name="razon_social">
 
                 </div> --}}
-                         <div class="mb-3 col-3">
+                <div class="mb-3 col-3">
+                    <label for="marca" class="form-label">Marca</label>
+                    <input type="text"  class="form-control" id="marca"
+                        value="{{ $datosdelequipo[0]->marca ?? '' }}"  placeholder="" name="marca">
+
+                </div>
+                <div class="mb-3 col-3">
+                    <label for="modelo" class="form-label">Modelo</label>
+                    <input type="text"  class="form-control" id="modelo"
+                        value="{{ $datosdelequipo[0]->modelo ?? '' }}"  placeholder=""
+                        name="modelo">
+
+                </div>
+                <div class="mb-3 col-3">
+                    <label for="motor" class="form-label">Motor</label>
+                    <input type="text"  class="form-control" id="motor"
+                        value="{{ $datosdelequipo[0]->motor ?? '' }}"  placeholder=""
+                        name="motor">
+
+                </div>
+                <div class="mb-3 col-3">
+                    <label for="ano_auto" class="form-label">Año</label>
+                    <input type="text"  class="form-control" id="ano_auto"
+                        value="{{ $datosdelequipo[0]->ano ?? '' }}"  placeholder=""
+                        name="ano_auto">
+
+                </div>
+                <div class="mb-3 col-3">
+                    <label for="serie" class="form-label">Serie</label>
+                    <input type="text"  class="form-control" id="serie"
+                        value="{{ $datosdelequipo[0]->serie ?? '' }}"  placeholder=""
+                        name="serie">
+
+                </div>
+             
+                <div class="col-md mt-2">
+                   <label for="">Combustible</label>
+                   <select class="form-control mayuscula" id="equipo_combustible" name="combustible"
+                       id="combustible">
+                       <option value="">Seleccionar</option>
+                       @if (!empty($combustibles))
+                           @foreach ($combustibles as $data)
+
+                           @if($datosdelequipo[0]->idcombustible  ==   $data->id)
+                               <option selected value="{{ $data->id }}">
+                                   {{ $data->nombre }}</option>
+
+                            @else
+                            <option  value="{{ $data->id }}">
+                               {{ $data->nombre }}</option>
+                            
+                            @endif
+                           @endforeach
+                       @endif
+                   </select>
+               </div>
+                
+                {{-- <div class="mb-3 col-3">
                              <label for="razon_social" class="form-label">Marca</label>
                              <input type="text" required class="form-control" id="razon_social"
                                  value="{{ $datosdelequipo[0]->marca ?? '' }}" disabled placeholder="" name="razon_social">
@@ -176,7 +251,7 @@
                                  value="{{ $datosdelequipo[0]->nombrecombustible ?? '' }}" disabled placeholder=""
                                  name="razon_social">
 
-                         </div>
+                         </div> --}}
                          {{-- <div class="mb-3 col-3">
                     <label for="razon_social" class="form-label">Patente</label>
                     <input type="text" required class="form-control" id="razon_social"
