@@ -6,7 +6,7 @@
     <div class="container">
         {{-- {{$repuestos_medidas}} --}}
 
-        <form action="{{ route('ordendetrabajo.manualstore') }}" method="POST" onsubmit="return validarFormulario()">
+        <form id="formulario_principal" action="{{ route('ordendetrabajo.manualstore') }}" method="POST" onsubmit="return validarFormulario()">
             @csrf
             {{-- Session 1 --}}
             <div class="row card mb-2" id="datosequipo" style="display: ">
@@ -605,7 +605,7 @@
                     <div style="text-align: right">
                         <input type="button" value="Atras" onclick="atras(2)" class="m-2">
 
-                        <input type="submit" value="Siguiente" class="m-2">
+                        <input type="submit" value="Siguiente" class="m-2" id="botonSiguiente">
                     </div>
 
                 </div> {{-- fin del card  session 23 --}}
@@ -1710,8 +1710,9 @@ $('#operario').html(radioButtons);
 
                     }else{
                         
-                        tr += "<td>" + "<input type='text' onchange='agregarDescripcioncOtro("+objeto.id+",this)'  id=descrip_repuesto"+objeto.id+"  value="+objeto.descripcionOtro+">" + "</td>";
-                        
+                      //  tr += "<td>" + "<input type='text' onchange='agregarDescripcioncOtro("+objeto.id+",this)'  id=descrip_repuesto"+objeto.id+"  value="+objeto.descripcionOtro+">" + "</td>";
+                      tr += "<td>" + "<input type='text' onchange='agregarDescripcioncOtro("+objeto.id+",this)' id='descrip_repuesto"+objeto.id+"' value='"+objeto.descripcionOtro+"'>" + "</td>";
+
                     }
                 // tr += "<td>" + (objeto.nombre || '').toUpperCase() + "</td>";
                 if(objeto.nombre != "OTRO"){
@@ -2267,6 +2268,8 @@ calcularTotalTable(1);
          if(contadorError >= 1){
             return false;
          }else{
+            $("#botonSiguiente").remove();
+            $("#formulario_principal").css("display","none");
             return true;
          }
 
