@@ -295,6 +295,8 @@
               @if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria")
               <th class="th-subhead border-th">Contacto</th>
               <th class="th-subhead border-th" style="width: 100px;">Rut</th>
+              <th class="th-subhead border-th" style="width: 100px;">Motor</th>
+
               <th class="th-subhead border-th">Operario encargado</th>
               <th class="th-subhead border-th"  style="width: 150px;" >Total</th>
               @endif
@@ -363,6 +365,16 @@
                     <td class="td-val">{{$los_datos->razon_social}}</td>
                     <td class="td-val">{{$los_datos->rut}}</td>
 
+                    <td class="td-val">
+                      {{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->marca}}
+                      {{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->modelo}}
+                      {{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->motor}}
+                      {{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->ano}}
+                      {{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->nombrecombustible}}
+
+
+                    </td>
+
                     <td class="td-val">{{$los_datos->nombre_completo}}</td>
 
               @endif
@@ -376,9 +388,13 @@
               <td class="td-val">{{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->nombrecombustible}}</td>
 
               @endif
+
+              @if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria")
+
               <td class="td-val">$
               {{number_format($los_datos->total_con_descuentos, 0, ',', '.')}}
               </td>
+              @endif
 
                 <td class="td-val">
                   
@@ -505,7 +521,10 @@
             @endif
           </tbody>
         </table>
-        {{ $ordenesdetrabajo->links('pagination::bootstrap-4') }}
+        {{-- {{ $ordenesdetrabajo->links('pagination::bootstrap-4') }}
+         --}}
+         {{ $ordenesdetrabajo->appends(request()->query())->links('pagination::bootstrap-4') }}
+
       </div>
       
 
@@ -897,7 +916,7 @@ function abrirModalAbonos(numeroDelaOt,idOt){
                             tr += "<td>" + reversedIndex+"</td>";
 
                               // tr += "<td>" + objeto.id + "</td>";
-                            tr += "<td>" + (formatearFecha(objeto.fecha_ingreso) || '').toUpperCase() + "</td>";
+                            tr += "<td>" + (formatearFecha(objeto.fecha_ingreso_actualizacion) || '').toUpperCase() + "</td>";
                        
                              tr += "<td>" + '<a style="cursor:pointer"  onclick="irOt(' + objeto.id + ')"  >' + "REVISAR" + "</a>" +
                                 "</td>";
@@ -987,6 +1006,13 @@ window.location.href = url; // Redirige a la URL completa
 
                       +'<td>'+v.razon_social+'</td>'  
                       +'<td>'+v.rut+'</td>'  
+                      +'<td>'+
+                        (v.marca ? v.marca : '') + " "+
+                      (v.modelo ? v.modelo : '') + " "+
+                      (v.motor ? v.motor : '') + " "+
+                      (v.ano ? v.ano : '') + " "+
+                      (v.nombre_combustible ? v.nombre_combustible : '') 
+                        +'</td>'  
 
                       +'<td>'+v.nombre_completo+'</td>'  
                       +'<td>'+"$"+format_js(v.total_con_descuentos) +'</td>'  
