@@ -3,7 +3,7 @@
     <div class="container">
         
 
-        <form action="<?php echo e(route('ordendetrabajo.manualstore')); ?>" method="POST" onsubmit="return validarFormulario()">
+        <form id="formulario_principal" action="<?php echo e(route('ordendetrabajo.manualstore')); ?>" method="POST" onsubmit="return validarFormulario()">
             <?php echo csrf_field(); ?>
             
             <div class="row card mb-2" id="datosequipo" style="display: ">
@@ -555,7 +555,7 @@
                     <div style="text-align: right">
                         <input type="button" value="Atras" onclick="atras(2)" class="m-2">
 
-                        <input type="submit" value="Siguiente" class="m-2">
+                        <input type="submit" value="Siguiente" class="m-2" id="botonSiguiente">
                     </div>
 
                 </div> 
@@ -1660,8 +1660,9 @@ $('#operario').html(radioButtons);
 
                     }else{
                         
-                        tr += "<td>" + "<input type='text' onchange='agregarDescripcioncOtro("+objeto.id+",this)'  id=descrip_repuesto"+objeto.id+"  value="+objeto.descripcionOtro+">" + "</td>";
-                        
+                      //  tr += "<td>" + "<input type='text' onchange='agregarDescripcioncOtro("+objeto.id+",this)'  id=descrip_repuesto"+objeto.id+"  value="+objeto.descripcionOtro+">" + "</td>";
+                      tr += "<td>" + "<input type='text' onchange='agregarDescripcioncOtro("+objeto.id+",this)' id='descrip_repuesto"+objeto.id+"' value='"+objeto.descripcionOtro+"'>" + "</td>";
+
                     }
                 // tr += "<td>" + (objeto.nombre || '').toUpperCase() + "</td>";
                 if(objeto.nombre != "OTRO"){
@@ -2217,6 +2218,8 @@ calcularTotalTable(1);
          if(contadorError >= 1){
             return false;
          }else{
+            $("#botonSiguiente").remove();
+            $("#formulario_principal").css("display","none");
             return true;
          }
 
