@@ -105,7 +105,7 @@ if ($posicion_coincidencia === false) {
 }
 /*****************************************************/
 /*****************************************************/
-$posicion_coincidencia = strpos($url, 'informes');
+$posicion_coincidencia = strpos($url, 'gohomei');
 if ($posicion_coincidencia === false) {
         $informes = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">minimize</span>';
             $padding_left_informes = "style='margin-left: 35px; opacity:0.5;'";
@@ -113,7 +113,10 @@ if ($posicion_coincidencia === false) {
     else{
             $informes = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">arrow_left</span>';
             $padding_left_informes = "style='margin-left: 35px;'";
+            $home = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">minimize</span>';
+            $padding_left_dashboard = "style='margin-left: 35px; opacity:0.5;'";
 }
+$agregar_gastos = '<span class="material-symbols-outlined" style="margin-left:30%; font-size:32px;">minimize</span>';
 /*****************************************************/
 /*****************************************************/
 $posicion_coincidencia = strpos($url, 'servicios');
@@ -217,9 +220,11 @@ if ($posicion_coincidencia === false) {
                                 $getSucursal =\App\Models\User::nameBranchId($getDataUser[0]->sucursales_id);
                                 $sucursal = base64_encode($getSucursal);
                                 ?>
-                               <a href="https://iretail.cl/gastos/?cl=<?php echo e($nebio1); ?>&n=<?php echo e($nombre); ?>&a=<?php echo e($apellido); ?>&s=<?php echo e($sucursal); ?>" class="nav-link py-3 px-2" title="" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-original-title="" target="_blank">
+                               
+                                <a href="<?php echo e(route('gohomeiframe', ['url' => base64_encode("agregargasto")])); ?>"  class="nav-link py-3 px-2" title="" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-original-title="" > 
+
                                 <div class="menu-item-wrapper">
-                                    <img src="<?php echo e(asset('img/iconos/gastos.png')); ?>" alt="Logo" class="icono-logo-menu" <?php echo $padding_left_informes; ?>><?php echo $informes; ?>
+                                    <img src="<?php echo e(asset('img/iconos/gastos.png')); ?>" alt="Logo" class="icono-logo-menu" <?php echo $padding_left_informes; ?>><?php echo $agregar_gastos; ?>
                                 </div>
                                 <b style="color: #fff;">Agregar gasto</b>
                             </a>
