@@ -101,20 +101,30 @@
 
                      </div>
 
+                     <div class="mb-3 col-3">
+                        <label for="" class="form-label">Fecha Ingreso</label>
+                        <?php if(isset($ordenes_trabajos[0]->fecha_ingreso)): ?>
+                            <input type="date" name="fecha_ingreso" class="form-control"
+                                value="<?php echo e(\Carbon\Carbon::createFromDate($ordenes_trabajos[0]->fecha_ingreso)->format('Y-m-d')); ?>">
+                        <?php else: ?>
+                            <input type="date" name="fecha_ingreso" class="form-control" value="">
+                        <?php endif; ?>
+                    
+                    </div>
 
-                     <div class="mb-3 col-6">
-                         <label for="" class="form-label">Fecha entrega</label>
 
-                         <?php if(isset($ordenes_trabajos[0]->fecha_entrega)): ?>
-                             <input type="date" name="fechaentrega" class="form-control"
-                                 value="<?php echo e(\Carbon\Carbon::createFromDate($ordenes_trabajos[0]->fecha_entrega)->format('Y-m-d')); ?>">
-                         <?php else: ?>
-                             <input type="date" name="fechaentrega" class="form-control" value="">
-                         <?php endif; ?>
-                         
-                         
+                     <div class="mb-3 col-3">
+                        <label for="" class="form-label">Fecha entrega</label>
+                        <?php if(isset($ordenes_trabajos[0]->fecha_entrega)): ?>
+                            <input type="date" name="fechaentrega" class="form-control"
+                                value="<?php echo e(\Carbon\Carbon::createFromDate($ordenes_trabajos[0]->fecha_entrega)->format('Y-m-d')); ?>">
+                        <?php else: ?>
+                            <input type="date" name="fechaentrega" class="form-control" value="">
+                        <?php endif; ?>
+                    
+                    </div>
 
-                     </div>
+                     
                      
                      <div class="mb-3 col-13">
                          <label for="" class="form-label">Comentario</label>
@@ -132,47 +142,64 @@
                          <label for="" class="m-2"> Datos del motor</label>
 
                          
-                         <div class="mb-3 col-3">
-                             <label for="razon_social" class="form-label">Marca</label>
-                             <input type="text" required class="form-control" id="razon_social"
-                                 value="<?php echo e($datosdelequipo[0]->marca ?? ''); ?>" disabled placeholder="" name="razon_social">
+                <div class="mb-3 col-3">
+                    <label for="marca" class="form-label">Marca</label>
+                    <input type="text"  class="form-control" id="marca"
+                        value="<?php echo e($datosdelequipo[0]->marca ?? ''); ?>"  placeholder="" name="marca">
 
-                         </div>
-                         <div class="mb-3 col-3">
-                             <label for="razon_social" class="form-label">Modelo</label>
-                             <input type="text" required class="form-control" id="razon_social"
-                                 value="<?php echo e($datosdelequipo[0]->modelo ?? ''); ?>" disabled placeholder=""
-                                 name="razon_social">
+                </div>
+                <div class="mb-3 col-3">
+                    <label for="modelo" class="form-label">Modelo</label>
+                    <input type="text"  class="form-control" id="modelo"
+                        value="<?php echo e($datosdelequipo[0]->modelo ?? ''); ?>"  placeholder=""
+                        name="modelo">
 
-                         </div>
-                         <div class="mb-3 col-3">
-                             <label for="razon_social" class="form-label">Motor</label>
-                             <input type="text" required class="form-control" id="razon_social"
-                                 value="<?php echo e($datosdelequipo[0]->motor ?? ''); ?>" disabled placeholder=""
-                                 name="razon_social">
+                </div>
+                <div class="mb-3 col-3">
+                    <label for="motor" class="form-label">Motor</label>
+                    <input type="text"  class="form-control" id="motor"
+                        value="<?php echo e($datosdelequipo[0]->motor ?? ''); ?>"  placeholder=""
+                        name="motor">
 
-                         </div>
-                         <div class="mb-3 col-3">
-                             <label for="razon_social" class="form-label">Año</label>
-                             <input type="text" required class="form-control" id="razon_social"
-                                 value="<?php echo e($datosdelequipo[0]->ano ?? ''); ?>" disabled placeholder=""
-                                 name="razon_social">
+                </div>
+                <div class="mb-3 col-3">
+                    <label for="ano_auto" class="form-label">Año</label>
+                    <input type="text"  class="form-control" id="ano_auto"
+                        value="<?php echo e($datosdelequipo[0]->ano ?? ''); ?>"  placeholder=""
+                        name="ano_auto">
 
-                         </div>
-                         <div class="mb-3 col-3">
-                             <label for="razon_social" class="form-label">Serie</label>
-                             <input type="text" required class="form-control" id="razon_social"
-                                 value="<?php echo e($datosdelequipo[0]->serie ?? ''); ?>" disabled placeholder=""
-                                 name="razon_social">
+                </div>
+                <div class="mb-3 col-3">
+                    <label for="serie" class="form-label">Serie</label>
+                    <input type="text"  class="form-control" id="serie"
+                        value="<?php echo e($datosdelequipo[0]->serie ?? ''); ?>"  placeholder=""
+                        name="serie">
 
-                         </div>
-                         <div class="mb-3 col-3">
-                             <label for="razon_social" class="form-label">Combustible</label>
-                             <input type="text" required class="form-control" id="razon_social"
-                                 value="<?php echo e($datosdelequipo[0]->nombrecombustible ?? ''); ?>" disabled placeholder=""
-                                 name="razon_social">
+                </div>
+             
+                <div class="col-md mt-2">
+                   <label for="">Combustible</label>
+                   <select class="form-control mayuscula" id="equipo_combustible" name="combustible"
+                       id="combustible">
+                       <option value="">Seleccionar</option>
+                       <?php if(!empty($combustibles)): ?>
+                           <?php $__currentLoopData = $combustibles; $__env->addLoop($__currentLoopData); foreach($__currentLoopData as $data): $__env->incrementLoopIndices(); $loop = $__env->getLastLoop(); ?>
 
-                         </div>
+                           <?php if($datosdelequipo[0]->idcombustible  ==   $data->id): ?>
+                               <option selected value="<?php echo e($data->id); ?>">
+                                   <?php echo e($data->nombre); ?></option>
+
+                            <?php else: ?>
+                            <option  value="<?php echo e($data->id); ?>">
+                               <?php echo e($data->nombre); ?></option>
+                            
+                            <?php endif; ?>
+                           <?php endforeach; $__env->popLoop(); $loop = $__env->getLastLoop(); ?>
+                       <?php endif; ?>
+                   </select>
+               </div>
+                
+                
                          
                      </div>
 
