@@ -325,6 +325,8 @@ unset($__errorArgs, $__bag); ?>
               <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria"): ?>
               <th class="th-subhead border-th">Contacto</th>
               <th class="th-subhead border-th" style="width: 100px;">Rut</th>
+              <th class="th-subhead border-th" style="width: 100px;">Motor</th>
+
               <th class="th-subhead border-th">Operario encargado</th>
               <th class="th-subhead border-th"  style="width: 150px;" >Total</th>
               <?php endif; ?>
@@ -377,6 +379,21 @@ unset($__errorArgs, $__bag); ?>
                     <td class="td-val"><?php echo e($los_datos->razon_social); ?></td>
                     <td class="td-val"><?php echo e($los_datos->rut); ?></td>
 
+                    <td class="td-val">
+                      <?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->marca); ?>
+
+                      <?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->modelo); ?>
+
+                      <?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->motor); ?>
+
+                      <?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->ano); ?>
+
+                      <?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->nombrecombustible); ?>
+
+
+
+                    </td>
+
                     <td class="td-val"><?php echo e($los_datos->nombre_completo); ?></td>
 
               <?php endif; ?>
@@ -390,10 +407,14 @@ unset($__errorArgs, $__bag); ?>
               <td class="td-val"><?php echo e(\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->nombrecombustible); ?></td>
 
               <?php endif; ?>
+
+              <?php if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria"): ?>
+
               <td class="td-val">$
               <?php echo e(number_format($los_datos->total_con_descuentos, 0, ',', '.')); ?>
 
               </td>
+              <?php endif; ?>
 
                 <td class="td-val">
                   
@@ -518,7 +539,9 @@ unset($__errorArgs, $__bag); ?>
             <?php endif; ?>
           </tbody>
         </table>
-        <?php echo e($ordenesdetrabajo->links('pagination::bootstrap-4')); ?>
+        
+         <?php echo e($ordenesdetrabajo->appends(request()->query())->links('pagination::bootstrap-4')); ?>
+
 
       </div>
       
@@ -912,7 +935,7 @@ function abrirModalAbonos(numeroDelaOt,idOt){
                             tr += "<td>" + reversedIndex+"</td>";
 
                               // tr += "<td>" + objeto.id + "</td>";
-                            tr += "<td>" + (formatearFecha(objeto.fecha_ingreso) || '').toUpperCase() + "</td>";
+                            tr += "<td>" + (formatearFecha(objeto.fecha_ingreso_actualizacion) || '').toUpperCase() + "</td>";
                        
                              tr += "<td>" + '<a style="cursor:pointer"  onclick="irOt(' + objeto.id + ')"  >' + "REVISAR" + "</a>" +
                                 "</td>";
@@ -1002,6 +1025,13 @@ window.location.href = url; // Redirige a la URL completa
 
                       +'<td>'+v.razon_social+'</td>'  
                       +'<td>'+v.rut+'</td>'  
+                      +'<td>'+
+                        (v.marca ? v.marca : '') + " "+
+                      (v.modelo ? v.modelo : '') + " "+
+                      (v.motor ? v.motor : '') + " "+
+                      (v.ano ? v.ano : '') + " "+
+                      (v.nombre_combustible ? v.nombre_combustible : '') 
+                        +'</td>'  
 
                       +'<td>'+v.nombre_completo+'</td>'  
                       +'<td>'+"$"+format_js(v.total_con_descuentos) +'</td>'  
